#!/usr/bin/perl -n

%scancode_map = (
 'escape', '0x01',
 'esc', '0x01',
 '1', '0x02',
 '2', '0x03',
 '3', '0x04',
 '4', '0x05',
 '5', '0x06',
 '6', '0x07',
 '7', '0x08',
 '8', '0x09',
 '9', '0x0a',
 '0', '0x0b',
 'us_-', '0x0c',
 'de_szlig', '0x0c',
 'de_eszet', '0x0c',
 'us_=', '0x0d',
 'de_\'', '0x0d',
 'backspace', '0x0e',
 'bs', '0x0e',
 'tabulator', '0x0f',
 'tab', '0x0f',
 'q', '0x10',
 'w', '0x11',
 'e', '0x12',
 'r', '0x13',
 't', '0x14',
 'us_y', '0x15',
 'de_z', '0x15',
 'u', '0x16',
 'i', '0x17',
 'o', '0x18',
 'p', '0x19',
 'us_[', '0x1a',
 'de_uuml', '0x1a',
 'us_]', '0x1b',
 'de_+', '0x1b',
 'return', '0x1c',
 'enter', '0x1c',
 'ret', '0x1c',
 'cr', '0x1c',

 'a', '0x1e',
 's', '0x1f',
 'd', '0x20',
 'f', '0x21',
 'g', '0x22',
 'h', '0x23',
 'j', '0x24',
 'k', '0x25',
 'l', '0x26',
 'us_;', '0x27',
 'de_ouml', '0x27',
 'us_\'', '0x28',
 'de_auml', '0x28',
 'us_\`', '0x29',
 'de_^', '0x29',

 'us_\\', '0x2b',
 'de_#', '0x2b',
 'us_z', '0x2c',
 'de_y', '0x2c',
 'x', '0x2d',
 'c', '0x2e',
 'v', '0x2f',
 'b', '0x30',
 'n', '0x31',
 'm', '0x32',
 ',', '0x33',
 '.', '0x34',
 'us_/', '0x35',
 'de_-', '0x35',
 'space', '0x39',
 'space_bar', '0x39',
 'sp', '0x39',
 'home', '0x47',
 'page_up', '0x49',
 'end', '0x4f',
 'page_down', '0x51',
 'insert', '0x52',
 'ins', '0x52',
 'delete', '0x53',
 'del', '0x53',
 'de_<', '0x56');

%value_map = (
 'none', '0xff',
 'nc', '0xff',
 'nul', '0x00',
 'soh', '0x01',
 'stx', '0x02',
 'etx', '0x03',
 'eot', '0x04',
 'enq', '0x05',
 'ack', '0x06',
 'bel', '0x07',
 'bs',  '0x08',
 'ht',  '0x09',
 'lf',  '0x0a',
 'vt',  '0x0b',
 'ff',  '0x0c',
 'cr',  '0x0d',
 'so',  '0x0e',
 'si',  '0x0f',
 'dle', '0x10',
 'dc1', '0x11',
 'dc2', '0x12',
 'dc3', '0x13',
 'dc4', '0x14',
 'nak', '0x15',
 'syn', '0x16',
 'etb', '0x17',
 'can', '0x18',
 'em',  '0x19',
 'sub', '0x1a',
 'esc', '0x1b',
 'fs',  '0x1c',
 'gs',  '0x1d',
 'rs',  '0x1e',
 'us',  '0x1f',
 'space', '0x20',
 'bang', '0x21',
 '!', '0x21',
 'double_quote', '0x22',
 '"', '0x22',
 'pound', '0x23',
 '#', '0x23',
 'dollar', '0x24',
 '$', '0x24',
 'percent', '0x25',
 '%', '0x25',
 'ampersand', '0x26',
 '&', '0x26',
 'single_quote', '0x27',
 '\'', '0x27',
 'parenleft', '0x28',
 '(', '0x28',
 'parenright', '0x29',
 ')', '0x29',
 'asterisk', '0x2a',
 '*', '0x2a',
 'plus', '0x2b',
 '+', '0x2b',
 'comma', '0x2c',
 ',', '0x2c',
 'minus', '0x2d',
 '-', '0x2d',
 'period', '0x2e',
 '.', '0x2e',
 'slash', '0x2f',
 '/', '0x2f',
 'zero', '0x30',
 '0', '0x30',
 'one', '0x31',
 '1', '0x31',
 'two', '0x32',
 '2', '0x32',
 'three', '0x33',
 '3', '0x33',
 'four', '0x34',
 '4', '0x34',
 'five', '0x35',
 '5', '0x35',
 'six', '0x36',
 '6', '0x36',
 'seven', '0x37',
 '7', '0x37',
 'eight', '0x38',
 '8', '0x38',
 'nine', '0x39',
 '9', '0x39',
 'colon', '0x3a',
 ':', '0x3a',
 'semicolon', '0x3b',
 ';', '0x3b',
 'lessthan', '0x3c',
 '<', '0x3c',
 'equal', '0x3d',
 '=', '0x3d',
 'greaterthan', '0x3e',
 '>', '0x3e',
 'questionmark', '0x3f',
 '?', '0x3f',
 'atsign', '0x40',
 '@', '0x40',
 'A', '0x41',
 'B', '0x42',
 'C', '0x43',
 'D', '0x44',
 'E', '0x45',
 'F', '0x46',
 'G', '0x47',
 'H', '0x48',
 'I', '0x49',
 'J', '0x4a',
 'K', '0x4b',
 'L', '0x4c',
 'M', '0x4d',
 'N', '0x4e',
 'O', '0x4f',
 'P', '0x50',
 'Q', '0x51',
 'R', '0x52',
 'S', '0x53',
 'T', '0x54',
 'U', '0x55',
 'V', '0x56',
 'W', '0x57',
 'X', '0x58',
 'Y', '0x59',
 'Z', '0x5a',
 'bracketleft', '0x5b',
 '[', '0x5b',
 'backslash', '0x5c',
 '\\', '0x5c',
 'bracketright', '0x5d',
 ']', '0x5d',
 'caret', '0x5e',
 '^', '0x5e',
 'underscore', '0x5f',
 '_', '0x5f',
 'grave', '0x60',
 '`', '0x60',
 'a', '0x61',
 'b', '0x62',
 'c', '0x63',
 'd', '0x64',
 'e', '0x65',
 'f', '0x66',
 'g', '0x67',
 'h', '0x68',
 'i', '0x69',
 'j', '0x6a',
 'k', '0x6b',
 'l', '0x6c',
 'm', '0x6d',
 'n', '0x6e',
 'o', '0x6f',
 'p', '0x70',
 'q', '0x71',
 'r', '0x72',
 's', '0x73',
 't', '0x74',
 'u', '0x75',
 'v', '0x76',
 'w', '0x77',
 'x', '0x78',
 'y', '0x79',
 'z', '0x7a',
 'bracketleft', '0x7b',
 '{', '0x7b',
 'pipe', '0x7c',
 '|', '0x7c',
 'bracketleft', '0x7d',
 '}', '0x7d',
 'tilde', '0x7e',
 '~', '0x7e',
 'del', '0x7f',

 'uuml', '0x81',
 'auml', '0x84',
 'Auml', '0x8e',
 'ouml', '0x94',
 'Ouml', '0x99',
 'Uuml', '0x9a',
 'alpha', '0xe0',
 'beta',  '0xe1',
 'Gamma', '0xe2',
 'pi',    '0xe3',
 'Sigma', '0xe4',
 'sigma', '0xe5',
 'mu',    '0xe6',
 'nu',    '0xe7',
 'circle','0xf8',
 'square','0xfd',

 'f1', '0x1b 0x4f 0x50',
 'f2', '0x1b 0x4f 0x51',
 'f3', '0x1b 0x4f 0x52',
 'f4', '0x1b 0x4f 0x53',
 'f5', '0x1b 0x4f 0x54',
 'f6', '0x1b 0x4f 0x55',
 'f7', '0x1b 0x4f 0x56',
 'f8', '0x1b 0x4f 0x57',
 'f9', '0x1b 0x4f 0x58',
 'f10', '0x1b 0x4f 0x59',
 'f11', '0x1b 0x4f 0x5a',
 'f12', '0x1b 0x4f 0x41',
 'f1_shift', '0x1b 0x4f 0x70',
 'f2_shift', '0x1b 0x4f 0x71',
 'f3_shift', '0x1b 0x4f 0x72',
 'f4_shift', '0x1b 0x4f 0x73',
 'f5_shift', '0x1b 0x4f 0x74',
 'f6_shift', '0x1b 0x4f 0x75',
 'f7_shift', '0x1b 0x4f 0x76',
 'f8_shift', '0x1b 0x4f 0x77',
 'f9_shift', '0x1b 0x4f 0x78',
 'f10_shift', '0x1b 0x4f 0x79',
 'f11_shift', '0x1b 0x4f 0x7a',
 'f12_shift', '0x1b 0x4f 0x61',
 'f1_alt', '0x1b 0x4f 0x30',
 'f2_alt', '0x1b 0x4f 0x31',
 'f3_alt', '0x1b 0x4f 0x32',
 'f4_alt', '0x1b 0x4f 0x33',
 'f5_alt', '0x1b 0x4f 0x34',
 'f6_alt', '0x1b 0x4f 0x35',
 'f7_alt', '0x1b 0x4f 0x36',
 'f8_alt', '0x1b 0x4f 0x37',
 'f9_alt', '0x1b 0x4f 0x38',
 'f10_alt', '0x1b 0x4f 0x39',
 'f11_alt', '0x1b 0x4f 0x3a',
 'f12_alt', '0x1b 0x4f 0x3b',
 'scrl', '0x1b 0x5b 0x4d',
 'home', '0x1b 0x5b 0x48',
 'up',   '0x1b 0x5b 0x41',
 'page_up', '0x1b 0x5b 0x56',
 'left', '0x1b 0x5b 0x44',
 'right', '0x1b 0x5b 0x43',
 'end', '0x1b 0x5b 0x59',
 'down', '0x1b 0x5b 0x49',
 'page_down', '0x1b 0x5b 0x55',
 'insert', '0x1b 0x5b 0x40',
 'ins', '0x1b 0x5b 0x40',
 'delete', '0x1b 0x5b 0x39');


next if /^\s*\#/;
chomp;
($scancode,@state) = split;
$scancode=$scancode_map{$scancode} if exists $scancode_map{$scancode};
$i=0;
while($i <= $#state && i <= 4) {
  next if $state[$i] eq 'skip';
  $state[$i] = $value_map{$state[$i]} if exists $value_map{$state[$i]};
  system("./set_key", "$i", "$scancode", split(/\s/,$state[$i]));
  $i++;
}
