#include <errno.h>
#include <error.h>
#include <stdlib.h>

#include <mach.h>
#include <device/device.h>
#include <hurd.h>

#define	IOCPARM_MASK	0x1fff		/* parameter length, at most 13 bits */
#define	IOC_IN		0x80000000U	/* copy in parameters */
#define _IOC(inout,group,num,len) \
	(inout | ((len & IOCPARM_MASK) << 16) | ((group) << 8) | (num))
#define	_IOW(g,n,t)	_IOC(IOC_IN,	(g), (n), sizeof(t))

/* From gnumach/i386/i386at/kd.h: */
#define NUMOUTPUT 3
struct kbentry {
  u_char kb_state;                /* which state to use */
  u_char kb_index;                /* which keycode */
  u_char kb_value[NUMOUTPUT];     /* value to get/set */
};
#define K_DONE		0xff
#define KDSKBENT	_IOW('k', 2, struct kbentry) /* set keybd entry */

int
main (int argc, char *argv[])
{
  error_t err;
  mach_port_t device, consdev;
  struct kbentry entry;

  if (argc < 4 || argc > 6)
    error (EXIT_FAILURE, 1, "invalid number of arguments");
  entry.kb_state = strtol(argv[1],0,0);
  entry.kb_index = strtol(argv[2],0,0);
  entry.kb_value[0] = strtol(argv[3],0,0);
  if (argc > 4)
    entry.kb_value[1] = strtol(argv[4],0,0);
  if (argc > 5)
    entry.kb_value[2] = strtol(argv[5],0,0);
  if (argc < 6)
    entry.kb_value[argc-3] = K_DONE;

  err = get_privileged_ports (NULL, &device);
  if (err)
    error (EXIT_FAILURE, err, "cannot get device master port");

  err = device_open (device, D_READ|D_WRITE, "console", &consdev);
  mach_port_deallocate (mach_task_self (), device);
  if (err)
    error (EXIT_FAILURE, err, "console");

  err = device_set_status (consdev, KDSKBENT, &entry,
			   (sizeof (struct kbentry)
			    + sizeof (natural_t) - 1)
			    / sizeof (natural_t) + 1);
  if (err)
    error (EXIT_FAILURE, err, "console (ioctl)");
  exit (EXIT_SUCCESS);
}
